==> qtjambi-qt3drender-6.3.2-sources.jar: io/qt/qt3d/render/QTechnique.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a Technique</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html">Qt3DRender::QTechnique</a></p>
 */
public class QTechnique extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechnique.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechnique(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechnique() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QTechnique(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechnique instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addFilterKey">Qt3DRender::QTechnique::addFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addParameter">Qt3DRender::QTechnique::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addRenderPass">Qt3DRender::QTechnique::addRenderPass(Qt3DRender::QRenderPass*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderPass(io.qt.qt3d.render.QRenderPass pass){
        addRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#filterKeys">Qt3DRender::QTechnique::filterKeys()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#parameters">Qt3DRender::QTechnique::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeFilterKey">Qt3DRender::QTechnique::removeFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeParameter">Qt3DRender::QTechnique::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeRenderPass">Qt3DRender::QTechnique::removeRenderPass(Qt3DRender::QRenderPass*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderPass(io.qt.qt3d.render.QRenderPass pass){
        removeRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#renderPasses">Qt3DRender::QTechnique::renderPasses()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses(){
        return renderPasses_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTechnique(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTechnique(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTechnique instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.2-sources.jar: io/qt/qt3d/render/QTechnique.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a Technique</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html">Qt3DRender::QTechnique</a></p>
 */
public class QTechnique extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechnique.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechnique(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechnique() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QTechnique(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechnique instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addFilterKey">Qt3DRender::QTechnique::addFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addParameter">Qt3DRender::QTechnique::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#addRenderPass">Qt3DRender::QTechnique::addRenderPass(Qt3DRender::QRenderPass*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderPass(io.qt.qt3d.render.QRenderPass pass){
        addRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#filterKeys">Qt3DRender::QTechnique::filterKeys()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#parameters">Qt3DRender::QTechnique::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeFilterKey">Qt3DRender::QTechnique::removeFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeParameter">Qt3DRender::QTechnique::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#removeRenderPass">Qt3DRender::QTechnique::removeRenderPass(Qt3DRender::QRenderPass*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderPass(io.qt.qt3d.render.QRenderPass pass){
        removeRenderPass_native_Qt3DRender_QRenderPass_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(pass));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderPass_native_Qt3DRender_QRenderPass_ptr(long __this__nativeId, long pass);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtechnique.html#renderPasses">Qt3DRender::QTechnique::renderPasses()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses(){
        return renderPasses_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.render.QRenderPass> renderPasses_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTechnique(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTechnique(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTechnique instance, QDeclarativeConstructor constructor);
    
}
